# Welcome to Nyckel

Nyckel is a Custom Classification API. It allows you to train, deploy and invoke custom [text](text_classification.md), [image](image_classification.md) and [tabular](tabular_classification.md) classification functions.

## Get started

* Visit [Nyckel](https://www.nyckel.com) and sign up for a free account.
* Install the SDK: `pip install nyckel`
* Check out the [Quickstart](quickstart.md) to get oriented.
* Explore the SDK for [text](text_classification.md), [image](image_classification.md) and [tabular](tabular_classification.md) classification.
